==> haskell-warp-quic-0.0.0-185-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-HhMbNPjoDB2iCeM67Zebb
key:                  warp-quic-0.0.0-HhMbNPjoDB2iCeM67Zebb
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  0bdec1425008fbfedcc5374538a160c0
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.2.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-HhMbNPjoDB2iCeM67Zebb
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    http3-0.0.2-3ckecP0oO6g9Czn2UFEtt8
    quic-0.1.6-6YvvIuEzYtPCDkiRFQieIp tls-1.8.0-H8NsUaBoeZf4tUx17BPTZh
    wai-3.2.4-JJVI15W7E9rGAtOPSLOeBU warp-3.3.30-DAHUlH7qmMW8GtlCwsSvsK

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-quic-0.0.0-186-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-JhcCXtl4dLr3KcbAarI1ob
key:                  warp-quic-0.0.0-JhcCXtl4dLr3KcbAarI1ob
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  24e970914ab92e8fb200cbcd2d624cc0
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.2.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-JhcCXtl4dLr3KcbAarI1ob
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    http3-0.0.2-3lZY4gY4n3fA61bbE102r8
    quic-0.1.6-4CFXGEgbaOaFphvPPuSR0F tls-1.8.0-3haHN370ZA3AIGLxPtgF82
    wai-3.2.4-BbAdcKGl4jbBaSv8iBtxy6 warp-3.3.30-h30kJzvF9BHT39ymLaaUc

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
